/* =================================
	COEFFICIENT FOR LENS FINDER CALCULATION
	PT-EW550
================================= */


// definition for optional lens ===========

var	optLens01 = 'ET-ELW31',	/*	0.74	to	0.96	(0.713-0.975)	trBp01-trBp03	*/
	optLens02 = 'ET-ELW30',	/*	0.96	to	1.22	(0.902-1.223)	trBp02-trBP05	*/
	optLensStd = 'Supplied Lens',	/*	1.22	to	2.26	(1.191-2.278)	trBP04-trBp07	*/
	optLens03 = 'ET-ELT30',	/*	2.23	to	4.02	(2.150-4.092)	trBp06-trBp09	*/
	optLens04 = 'ET-ELT31';	/*	4.02	to	7.20	(3.976 (3.9759)-7.338)	trBp08-trBp10	*/


// coefficient for projection range ===========

var	optLens = [ 'ET-ELW31', 'ET-ELW30', 'Supplied Lens', 'ET-ELT30', 'ET-ELT31' ];

var	coefAmin = [
		[ 16.187, 20.263, 26.501, 49.127, 85.400 ],	// 16:10
		[ 16.637, 20.826, 27.238, 50.493, 87.774 ]	// 16:9
	 ],
	coefBmin = [
		[ 32.405, 32.636, 32.581, 110.870, -100.100 ],
		[ 32.405, 32.636, 32.581, 110.870, -100.100 ]
	 ],
	coefAmax = [
		[ 21.069, 26.403, 49.125, 88.455, 155.67 ],
		[ 21.655, 27.137, 50.491, 90.914, 159.998 ]
	 ],
	coefBmax = [
		[ 34.396, 34.070, 32.822, 136.410, -93.980 ],
		[ 34.396, 34.070, 32.822, 136.410, -93.980 ]
	 ];


// link to throw distance calculator ===========

var	linkLens = [ 'elw31', 'elw30', '', 'elt30', 'elt31' ],
	linkLens1,
	linkLens2;


// option lens throw ratio range ===========

var	trRange = [
	[ '0.74', '0.96' ],
	[ '0.96', '1.22' ],
	[ '1.22', '2.26' ],
	[ '2.23', '4.02' ],
	[ '4.02', '7.20' ]
	];


// break point of projection range (throw ratio break point) ===========

		// 'No lens found'
var	trBp01 = 0.713,
		// optLens01
	trBp02 = 0.902,
		// optLens01 + optLens02
	trBp03 = 0.975,
		// optLens02
	trBp04 = 1.191,
		// optLens02 + optLensStd
	trBp05 = 1.223,
		// optLensStd
	trBp06 = 2.150,
		// optLensStd + optLens03
	trBp07 = 2.278,
		// optLens03
	trBp08 = 3.9759,
		// optLens03 + optLens04
	trBp09 = 4.092,
		// optLens04
	trBp10 = 7.338;
		// 'No lens found'


// option lens throw ratio range for canvas indicator ===========

var	trRangeBar = trRange
/*
var	trRangeBar = [
	[ trBp01, trBp03 ],
	[ trBp02, trBp05 ],
	[ trBp04, trBp07 ],
	[ trBp06, trBp09 ],
	[ trBp08, trBp10 ]
	];
*/


// size limitation ===========

var	scrnSizeMin = 40,
	scrnSizeMax = 400,
	scrnSizeMinMm = scrnSizeMin * 25.4,
	scrnSizeMaxMm = scrnSizeMax * 25.4;

	scrnSizeMax = String( scrnSizeMax ).replace( /(\d)(?=(\d\d\d)+(?!\d))/g, '$1,' );
	scrnSizeMinMm = String( scrnSizeMinMm ).replace( /(\d)(?=(\d\d\d)+(?!\d))/g, '$1,' );
	scrnSizeMaxMm = String( scrnSizeMaxMm ).replace( /(\d)(?=(\d\d\d)+(?!\d))/g, '$1,' );



// CALCULATION FOR SUITABLE LENS /////////////////////////


function lensFinder() {



	var	stLens1 = '',
		stLens2 = '',
		trMin1 = 0,
		trMax1 = 0,
		trLens1 = 0,
		trMin2 = 0,
		trMax2 = 0,
		trLens2 = 0,
		coefAmin1 = 0,
		coefBmin1 = 0,
		coefAmax1 = 0,
		coefBmax1 = 0,
		coefAmin2 = 0,
		coefBmin2 = 0,
		coefAmax2 = 0,
		coefBmax2 = 0;


	// aspect ratio

	var	aspectRatio = (function() {

		var	aspect = document.getElementsByName('aspect');

		for ( var i = 0; i < aspect.length; i++ ) {

			if ( aspect[i].checked == true ) {
				var	aspectRatio = aspect[i].value;
				return aspectRatio;		// ESSENTIAL
			}
		}

	}());


	// calculation

	if ( throwRatio < trBp01 ) {
		stLens1 = 'No lens was found.';
		linkLens1 = linkLens[0];
	} else if ( throwRatio <= trBp02 ) {
		stLens1 = optLens01;
		linkLens1 = linkLens[0];
		trMin1 = trRange[0][0];
		trMax1 = trRange[0][1];
		coefAmin1 = coefAmin[0][0];
		coefBmin1 = coefBmin[0][0];
		coefAmax1 = coefAmax[0][0];
		coefBmax1 = coefBmax[0][0];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][0];
			coefBmin1 = coefBmin[1][0];
			coefAmax1 = coefAmax[1][0];
			coefBmax1 = coefBmax[1][0];
		}
	} else if ( throwRatio <= trBp03 ) {
		// lens1
		stLens1 = optLens01;
		linkLens1 = linkLens[0];
		trMin1 = trRange[0][0];
		trMax1 = trRange[0][1];
		coefAmin1 = coefAmin[0][0];
		coefBmin1 = coefBmin[0][0];
		coefAmax1 = coefAmax[0][0];
		coefBmax1 = coefBmax[0][0];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][0];
			coefBmin1 = coefBmin[1][0];
			coefAmax1 = coefAmax[1][0];
			coefBmax1 = coefBmax[1][0];
		}
		// lens2
		stLens2 = optLens02;
		linkLens2 = linkLens[1];
		trMin2 = trRange[1][0];
		trMax2 = trRange[1][1];
		coefAmin2 = coefAmin[0][1];
		coefBmin2 = coefBmin[0][1];
		coefAmax2 = coefAmax[0][1];
		coefBmax2 = coefBmax[0][1];
		if ( aspectRatio == 169 ) {
			coefAmin2 = coefAmin[1][1];
			coefBmin2 = coefBmin[1][1];
			coefAmax2 = coefAmax[1][1];
			coefBmax2 = coefBmax[1][1];
		}
	} else if ( throwRatio <= trBp04 ) {
		stLens1 = optLens02;
		linkLens1 = linkLens[1];
		trMin1 = trRange[1][0];
		trMax1 = trRange[1][1];
		coefAmin1 = coefAmin[0][1];
		coefBmin1 = coefBmin[0][1];
		coefAmax1 = coefAmax[0][1];
		coefBmax1 = coefBmax[0][1];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][1];
			coefBmin1 = coefBmin[1][1];
			coefAmax1 = coefAmax[1][1];
			coefBmax1 = coefBmax[1][1];
		}
	} else if ( throwRatio <= trBp05 ) {
		// lens1
		stLens1 = optLens02;
		linkLens1 = linkLens[1];
		trMin1 = trRange[1][0];
		trMax1 = trRange[1][1];
		coefAmin1 = coefAmin[0][1];
		coefBmin1 = coefBmin[0][1];
		coefAmax1 = coefAmax[0][1];
		coefBmax1 = coefBmax[0][1];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][1];
			coefBmin1 = coefBmin[1][1];
			coefAmax1 = coefAmax[1][1];
			coefBmax1 = coefBmax[1][1];
		}
		// lens2
		stLens2 = optLensStd;
		linkLens2 = linkLens[2];
		trMin2 = trRange[2][0];
		trMax2 = trRange[2][1];
		coefAmin2 = coefAmin[0][2];
		coefBmin2 = coefBmin[0][2];
		coefAmax2 = coefAmax[0][2];
		coefBmax2 = coefBmax[0][2];
		if ( aspectRatio == 169 ) {
			coefAmin2 = coefAmin[1][2];
			coefBmin2 = coefBmin[1][2];
			coefAmax2 = coefAmax[1][2];
			coefBmax2 = coefBmax[1][2];
		}
	} else if ( throwRatio <= trBp06 ) {
		stLens1 = optLensStd;
		linkLens1 = linkLens[2];
		trMin1 = trRange[2][0];
		trMax1 = trRange[2][1];
		coefAmin1 = coefAmin[0][2];
		coefBmin1 = coefBmin[0][2];
		coefAmax1 = coefAmax[0][2];
		coefBmax1 = coefBmax[0][2];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][2];
			coefBmin1 = coefBmin[1][2];
			coefAmax1 = coefAmax[1][2];
			coefBmax1 = coefBmax[1][2];
		}
	} else if ( throwRatio <= trBp07 ) {
		// lens1
		stLens1 = optLensStd;
		linkLens1 = linkLens[2];
		trMin1 = trRange[2][0];
		trMax1 = trRange[2][1];
		coefAmin1 = coefAmin[0][2];
		coefBmin1 = coefBmin[0][2];
		coefAmax1 = coefAmax[0][2];
		coefBmax1 = coefBmax[0][2];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][2];
			coefBmin1 = coefBmin[1][2];
			coefAmax1 = coefAmax[1][2];
			coefBmax1 = coefBmax[1][2];
		}
		// lens2
		stLens2 = optLens03;
		linkLens2 = linkLens[3];
		trMin2 = trRange[3][0];
		trMax2 = trRange[3][1];
		coefAmin2 = coefAmin[0][3];
		coefBmin2 = coefBmin[0][3];
		coefAmax2 = coefAmax[0][3];
		coefBmax2 = coefBmax[0][3];
		if ( aspectRatio == 169 ) {
			coefAmin2 = coefAmin[1][3];
			coefBmin2 = coefBmin[1][3];
			coefAmax2 = coefAmax[1][3];
			coefBmax2 = coefBmax[1][3];
		}
	} else if ( throwRatio <= trBp08 ) {
		stLens1 = optLens03;
		linkLens1 = linkLens[3];
		trMin1 = trRange[3][0];
		trMax1 = trRange[3][1];
		coefAmin1 = coefAmin[0][3];
		coefBmin1 = coefBmin[0][3];
		coefAmax1 = coefAmax[0][3];
		coefBmax1 = coefBmax[0][3];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][3];
			coefBmin1 = coefBmin[1][3];
			coefAmax1 = coefAmax[1][3];
			coefBmax1 = coefBmax[1][3];
		}
	} else if ( throwRatio <= trBp09 ) {
		// lens1
		stLens1 = optLens03;
		linkLens1 = linkLens[3];
		trMin1 = trRange[3][0];
		trMax1 = trRange[3][1];
		coefAmin1 = coefAmin[0][3];
		coefBmin1 = coefBmin[0][3];
		coefAmax1 = coefAmax[0][3];
		coefBmax1 = coefBmax[0][3];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][3];
			coefBmin1 = coefBmin[1][3];
			coefAmax1 = coefAmax[1][3];
			coefBmax1 = coefBmax[1][3];
		}
		// lens2
		stLens2 = optLens04;
		linkLens2 = linkLens[4];
		trMin2 = trRange[4][0];
		trMax2 = trRange[4][1];
		coefAmin2 = coefAmin[0][4];
		coefBmin2 = coefBmin[0][4];
		coefAmax2 = coefAmax[0][4];
		coefBmax2 = coefBmax[0][4];
		if ( aspectRatio == 169 ) {
			coefAmin2 = coefAmin[1][4];
			coefBmin2 = coefBmin[1][4];
			coefAmax2 = coefAmax[1][4];
			coefBmax2 = coefBmax[1][4];
		}
	} else if ( throwRatio <= trBp10 ) {
		stLens1 = optLens04;
		linkLens1 = linkLens[4];
		trMin1 = trRange[4][0];
		trMax1 = trRange[4][1];
		coefAmin1 = coefAmin[0][4];
		coefBmin1 = coefBmin[0][4];
		coefAmax1 = coefAmax[0][4];
		coefBmax1 = coefBmax[0][4];
		if ( aspectRatio == 169 ) {
			coefAmin1 = coefAmin[1][4];
			coefBmin1 = coefBmin[1][4];
			coefAmax1 = coefAmax[1][4];
			coefBmax1 = coefBmax[1][4];
		}
	} else {
		stLens1 = 'No lens was found.';
		linkLens1 = linkLens[4];
	}

	var	pjRange1 = 0,
		pjRange1Ft = 0,
		pjRmin1 = 0,
		pjRmin1Ft = 0,
		pjRmax1 = 0,
		pjRmax1Ft = 0,
		pjRange2 = 0,
		pjRange2Ft = 0,
		pjRmin2 = 0,
		pjRmin2Ft = 0,
		pjRmax2 = 0,
		pjRmax2Ft = 0;

	// projection range

		pjRmin1 = Math.round( scrnDiag / 25.4 * coefAmin1 - coefBmin1 );
		pjRmin1Ft = Math.round(( scrnDiag / 25.4 * coefAmin1 - coefBmin1 ) / 25.4 / 12 * 100 ) / 100;
		pjRmax1 = Math.round( scrnDiag / 25.4 * coefAmax1 - coefBmax1 );
		pjRmax1Ft = Math.round(( scrnDiag / 25.4 * coefAmax1 - coefBmax1 ) / 25.4 / 12 * 100 ) / 100;
		pjRmin2 = Math.round( scrnDiag / 25.4 * coefAmin2 - coefBmin2 );
		pjRmin2Ft = Math.round(( scrnDiag / 25.4 * coefAmin2 - coefBmin2 ) / 25.4 / 12 * 100 ) / 100;
		pjRmax2 = Math.round( scrnDiag / 25.4 * coefAmax2 - coefBmax2 );
		pjRmax2Ft = Math.round(( scrnDiag / 25.4 * coefAmax2 - coefBmax2 ) / 25.4 / 12 * 100 ) / 100;

		// zoom lens

		if ( pjRmax1 != 0 ) {

			trLens1 = ' (' + trMin1 + '–' + trMax1 + ':1)';
			pjRange1 = pjRmin1.toLocaleString() + '–' + pjRmax1.toLocaleString() + ' millimeters';
			pjRange1Ft = pjRmin1Ft.toLocaleString() + '–' + pjRmax1Ft.toLocaleString() + ' feet';

			if ( pjRmax2 != 0 ) {
				trLens2 = ' (' + trMin2 + '–' + trMax2 + ':1)';
				pjRange2 = pjRmin2.toLocaleString() + '–' + pjRmax2.toLocaleString() + ' millimeters';
				pjRange2Ft = pjRmin2Ft.toLocaleString() + '–' + pjRmax2Ft.toLocaleString() + ' feet';
			}

			else if ( pjRmin2 != 0 ) {
				trLens2 = ' (' + trMin2 + ':1)';
				pjRange2 = pjRmin2 + ' millimeters';
				pjRange2Ft = pjRmin2Ft + ' feet';
			}

		}

		// fixed lens or no suitable lens

		else if ( pjRmin1 != 0 ) {
			trLens1 = ' (' + trMin1 + ':1)';
			pjRange1 = pjRmin1 + ' millimeters';
			pjRange1Ft = pjRmin1Ft + ' feet';
		}


	var	stLensH2= document.getElementById('option-lens-title');
		stLensDiv1 = document.getElementById('option-lens-1'),
		stLensDiv2 = document.getElementById('option-lens-2'),
		throwRatioDiv = document.getElementById('calculated-throw-ratio'),
		pjRangeDiv = document.getElementById('projection-range-title'),
		pjRangeDiv1 = document.getElementById('projection-range-1'),
		pjRangeDiv2 = document.getElementById('projection-range-2'),
		elBr1 = document.createElement('br'),
		elBr2 = document.createElement('br'),
		aLens1 = document.createElement('a'),
		aLens2 = document.createElement('a'),
		// for recalculation
		stLensOldTitle = document.getElementById('option-lens-title').firstChild,
		stLensOldText1 = document.getElementById('option-lens-1').firstChild,
		stLensOldText2 = document.getElementById('option-lens-2').firstChild,
		throwRatioOldText = document.getElementById('calculated-throw-ratio').firstChild,
		pjRangeOldTitle = document.getElementById('projection-range-title').firstChild,
		pjRangeOldText1 = document.getElementById('projection-range-1').firstChild,
		pjRangeOldText2 = document.getElementById('projection-range-2').firstChild,
		// results
		stLensTitle = document.createTextNode('Suitable Lens: '),
		stLensText1 = document.createTextNode(stLens1),
		stLensText2 = document.createTextNode(stLens2);
/*		if ( stLens1 == 'ET-ELW21' ) {
			var	stLensText1 = document.createTextNode('The ' + stLens1 + ' can be suitable.');
		} else {
			var	stLensText1 = document.createTextNode(stLens1);
		}
		if ( stLens2 == 'ET-ELW21' ) {
			var	stLensText2 = document.createTextNode('The ' + stLens2 + ' can be suitable.');
		} else {
			var	stLensText2 = document.createTextNode(stLens2);
		}
*/
		// link to throw distance calculator
	var	linkCalc1 = '../installation/ew550' + linkLens1 + '.html?' + encodeURIComponent(scrnSize) + '&' + encodeURIComponent(aspectRatio) + '&' + encodeURIComponent(scrnUnit) + '&' + encodeURIComponent(scrnPortion),
		linkCalc2 = '../installation/ew550' + linkLens2 + '.html?' + encodeURIComponent(scrnSize) + '&' + encodeURIComponent(aspectRatio) + '&' + encodeURIComponent(scrnUnit) + '&' + encodeURIComponent(scrnPortion);

		aLens1.href = linkCalc1;
		aLens2.href = linkCalc2;
		throwRatioText = document.createTextNode('Approximate throw ratio of this condition: ' + (Math.round(throwRatio * 10) / 10).toFixed(1) + ':1');
		pjRangeTitle = document.createTextNode('Projection distance for the requested image size: ');
		lensModel1 = document.createTextNode(stLens1 + trLens1 + ': ');
		pjRangeText1 = document.createTextNode(pjRange1 +'; ' + pjRange1Ft);
		lensModel2 = document.createTextNode(stLens2 + trLens2 + ': ');
		pjRangeText2 = document.createTextNode(pjRange2 +'; ' + pjRange2Ft);


	// reset on change

	if ( stLensOldText1 != null ) {

		stLensH2.removeChild(stLensOldTitle);
		stLensDiv1.removeChild(stLensOldText1);
		throwRatioDiv.removeChild(throwRatioOldText);

		if ( pjRangeOldTitle != null ) {
		pjRangeDiv.removeChild(pjRangeOldTitle);

			while ( pjRangeDiv1.lastChild ) {
			  pjRangeDiv1.removeChild(pjRangeDiv1.lastChild);
			}

			if ( stLensOldText2 != null ) {
				stLensDiv2.removeChild(stLensOldText2);
				while ( pjRangeDiv2.lastChild ) {
				  pjRangeDiv2.removeChild(pjRangeDiv2.lastChild);
				}

			}

		}

	}


	// OUTPUT ////////////

	stLensH2.appendChild(stLensTitle);	// Suitable Lens:
	throwRatioDiv.appendChild(throwRatioText);
	if ( stLens1 == 'No lens was found.' ) {

		stLensDiv1.appendChild(aLens1);		// lens model with link 1
		aLens1.appendChild(stLensText1);	// lens model 1

	} else if ( stLens1 != '' ) {

		stLensDiv1.appendChild(aLens1);		// lens model with link 1
		aLens1.appendChild(stLensText1);	// lens model 1
		pjRangeDiv.appendChild(pjRangeTitle);
		pjRangeDiv1.appendChild(lensModel1);
		pjRangeDiv1.appendChild(elBr1);
		pjRangeDiv1.appendChild(pjRangeText1);

		if ( stLens2 != '' ) {

			stLensDiv2.appendChild(aLens2);		// lens model with link 2
			aLens2.appendChild(stLensText2);	// lens model 2
			pjRangeDiv2.appendChild(lensModel2);
			pjRangeDiv2.appendChild(elBr2);
			pjRangeDiv2.appendChild(pjRangeText2);

		}

	}



}